---
feature_story: FS_80_45_89_81
feature_title: meta functions
feature_status: TODO
---

Meta functions are those built-in ones which are not domain-specific.

List:
*   `intercept_func`: [FS_88_66_66_73][FS_88_66_66_73]
*   `list_envelope`
*   `get_envelope`: TODO: should work as (A) query single envelope (with zero error code), otherwise (B) see `list_envelope` (with non-zero error code).
*   `set_envelope`: TODO: should work as (A) del prev queried envelope, (B) add next provided envelope body.
*   `dump_config`: TODO: dump server or client config view.
*   `echo_args`: TODO: echo to test arbitrary tail args. It can also serve as a test for FS_92_75_93_01.clean_command_line.md.


FS_88_66_66_73: FS_88_66_66_73.intercept_func.md
